@@ -29,8 +29,6 @@ from .config import render_string
 server_version = devpi_server.__version__
 
 
-MAXDOCZIPSIZE = 30 * 1024 * 1024    # 30MB
-
 H_MASTER_UUID = str("X-DEVPI-MASTER-UUID")
 
 
@@ -279,7 +277,7 @@ class PyPIView:
                  request_method="POST")
     def post_toxresult(self):
         stage = self.context.stage
-        relpath = self.request.path.strip("/")
+        relpath = self.request.path_info.strip("/")
         link = stage.get_link_from_entrypath(relpath)
         if link is None or link.rel != "releasefile":
             apireturn(404, message="no release file found at %s" % relpath)
@@ -316,7 +314,7 @@ class PyPIView:
         for link in result:
             relpath = link.entrypath
             href = "/" + relpath
-            href = URL(request.path).relpath(href)
+            href = URL(request.path_info).relpath(href)
             if link.eggfragment:
                 href += "#egg=%s" % link.eggfragment
             elif link.md5:
@@ -637,9 +635,6 @@ class PyPIView:
                             (jenkinurl,))
             else:
                 doczip = content.file.read()
-                if len(doczip) > MAXDOCZIPSIZE:
-                    abort_submit(413, "zipfile size %d too large, max=%s"
-                                   % (len(doczip), MAXDOCZIPSIZE))
                 try:
                     link = stage.store_doczip(name, version, doczip)
                 except stage.MissesRegistration:
@@ -774,7 +769,7 @@ class PyPIView:
     @view_config(route_name="/{user}/{index}/+f/{relpath:.*}")
     def pkgserv(self):
         request = self.request
-        relpath = request.path.strip("/")
+        relpath = request.path_info.strip("/")
         if "#" in relpath:   # XXX unclear how this happens (did with bottle)
             relpath = relpath.split("#", 1)[0]
         filestore = self.xom.filestore
@@ -784,7 +779,10 @@ class PyPIView:
                 apireturn(404, "no such release file")
             apireturn(200, type="releasefilemeta", result=entry.meta)
         if not entry or not entry.meta:
-            abort(request, 404, "no such file")
+            if entry is None:
+                abort(request, 404, "no such file")
+            else:
+                abort(request, 410, "file existed, deleted in later serial")
 
         if not entry.file_exists() or entry.eggfragment:
             keyfs = self.xom.keyfs
@@ -928,11 +926,11 @@ def trigger_jenkins(request, stage, jenkinurl, testspec):
     source = render_string("devpibootstrap.py",
         INDEXURL=baseurl + "/" + stage.name,
         VIRTUALENVTARURL= (baseurl +
-            "root/pypi/+f/d3d/915836c1ada1be731ccaa12412b98/"
-            "virtualenv-1.11.2.tar.gz",
+            "/root/pypi/+f/f61/cdd983d2c4e6a/"
+            "virtualenv-1.11.6.tar.gz"
             ),
         TESTSPEC=testspec,
-        DEVPI_INSTALL_INDEX = baseurl + stage.name + "/+simple/"
+        DEVPI_INSTALL_INDEX = baseurl + "/" + stage.name + "/+simple/"
     )
     inputfile = py.io.BytesIO(source.encode("ascii"))
     session = new_requests_session(agent=("server", server_version))
