@@ -384,10 +384,7 @@ class Mapp(MappMixin):
         r = self.testapp.patch_json("/%s" % user, reqdict, expect_errors=True)
         assert r.status_code == code
         if code == 200:
-            res = r.json["result"]
-            assert res["username"] == user
-            for name, val in reqdict.items():
-                assert res[name] == val
+            assert r.json == dict(message="user updated")
 
     def create_user_fails(self, user, password, email="hello@example.com"):
         with pytest.raises(webtest.AppError) as excinfo:
@@ -575,6 +572,13 @@ class Mapp(MappMixin):
             self._wait_for_serial_in_result(r)
         return r
 
+    def upload_toxresult(self, path, content, code=200, waithooks=False):
+        r = self.testapp.post(path, content, expect_errors=True)
+        assert r.status_code == code
+        if waithooks:
+            self._wait_for_serial_in_result(r)
+        return r
+
     def get_simple(self, projectname, code=200):
         r = self.testapp.get(self.api.simpleindex + projectname,
                              expect_errors=True)
