@@ -332,6 +332,20 @@ class TestTransactionIsolation:
         new_keyfs.import_changes(0, changes)
         assert l[0][1:] == (new_keyfs.NAME(name="world"), {1:1}, -1)
 
+    def test_import_changes_subscriber_error(self, keyfs, tmpdir):
+        pkey = keyfs.add_key("NAME", "hello/{name}", dict)
+        D = pkey(name="world")
+        with keyfs.transaction(write=True):
+            D.set({1:1})
+        new_keyfs = KeyFS(tmpdir.join("newkeyfs"))
+        pkey = new_keyfs.add_key("NAME", "hello/{name}", dict)
+        new_keyfs.subscribe_on_import(pkey, lambda *args: 0/0)
+        serial = new_keyfs.get_current_serial()
+        changes = keyfs._fs.get_changes(0)
+        with pytest.raises(ZeroDivisionError):
+            new_keyfs.import_changes(0, changes)
+        assert new_keyfs.get_current_serial() == serial
+
     def test_get_raw_changelog_entry_not_exist(self, keyfs):
         assert keyfs._fs.get_raw_changelog_entry(10000) is None
 
