@@ -177,17 +177,6 @@ class TestStage:
         assert links[2].basename == "some_project-1.0.tar.gz"
         assert stage.list_projectnames_perstage() == set(["some-project"])
 
-    def test_get_releaselinks_inheritance_shadow(self, pypistage, stage):
-        stage.modify(bases=("root/pypi",), pypi_whitelist=['someproject'])
-        pypistage.mock_simple("someproject",
-            "<a href='someproject-1.0.zip' /a>")
-        register_and_store(stage, "someproject-1.0.zip", b"123")
-        stage.store_releasefile("someproject", "1.0",
-                                "someproject-1.0.zip", b"123")
-        links = stage.get_releaselinks("someproject")
-        assert len(links) == 1
-        assert links[0].entrypath.endswith("someproject-1.0.zip")
-
     def test_inheritance_tolerance_on_different_names(self, stage, user):
         register_and_store(stage, "some_project-1.2.tar.gz",
                            name="some-project")
@@ -202,6 +191,17 @@ class TestStage:
         links = stage2.get_releaselinks("some_project")
         assert len(links) == 1
 
+    def test_get_releaselinks_inheritance_shadow(self, pypistage, stage):
+        stage.modify(bases=("root/pypi",), pypi_whitelist=['someproject'])
+        pypistage.mock_simple("someproject",
+            "<a href='someproject-1.0.zip' /a>")
+        register_and_store(stage, "someproject-1.0.zip", b"123")
+        stage.store_releasefile("someproject", "1.0",
+                                "someproject-1.0.zip", b"123")
+        links = stage.get_releaselinks("someproject")
+        assert len(links) == 1
+        assert links[0].entrypath.endswith("someproject-1.0.zip")
+
     def test_get_releaselinks_inheritance_shadow_egg(self, pypistage, stage):
         stage.modify(bases=("root/pypi",), pypi_whitelist=['py'])
         pypistage.mock_simple("py",
@@ -240,7 +240,8 @@ class TestStage:
 
     def test_store_and_get_releasefile(self, stage, bases):
         content = b"123"
-        entry = register_and_store(stage, "some-1.0.zip", content)
+        link = register_and_store(stage, "some-1.0.zip", content)
+        entry = link.entry
         assert entry.last_modified != None
         entries = stage.get_releaselinks("some")
         assert len(entries) == 1
@@ -460,11 +461,11 @@ class TestStage:
 
     def test_storetoxresult(self, stage, bases):
         content = b'123'
-        entry = register_and_store(stage, "pkg1-1.0.tar.gz", content=content)
+        link = register_and_store(stage, "pkg1-1.0.tar.gz", content=content)
+        entry = link.entry
         assert entry.projectname == "pkg1"
         assert entry.version == "1.0"
         toxresultdata = {'hello': 'world'}
-        link = stage.get_link_from_entrypath(entry.relpath)
         tlink = stage.store_toxresult(link, toxresultdata)
         assert tlink.entry.file_exists()
         linkstore = stage.get_linkstore_perstage("pkg1", "1.0")
@@ -493,9 +494,8 @@ class TestStage:
         assert len(stage.get_releaselinks("some")) == 1
 
         # rewrite  fails because index is non-volatile
-        entry = stage.store_releasefile("some", "1.0",
-                                        "some-1.0.zip", content2)
-        assert entry == 409
+        with pytest.raises(stage.NonVolatile):
+            stage.store_releasefile("some", "1.0", "some-1.0.zip", content2)
 
         # rewrite succeeds with volatile
         stage.modify(volatile=True)
