@@ -73,6 +73,24 @@ def test_simple_project(pypistage, testapp):
     assert len(links) == 1
     assert links[0].get("href").endswith(path)
 
+@pytest.mark.parametrize("outside_url", ['', 'http://localhost/devpi'])
+def test_simple_project_outside_url_subpath(mapp, outside_url, pypistage, testapp):
+    api = mapp.create_and_use()
+    mapp.upload_file_pypi(
+        "qpwoei-1.0.tar.gz", b'123', "qpwoei", "1.0", indexname=api.stagename)
+    pypistage.mock_simple("qpwoei", text='<a href="/qpwoei-1.0.zip"/>')
+    headers={str('X-outside-url'): str(outside_url)}
+    r = testapp.get("/%s/+simple/qpwoei" % api.stagename, headers=headers)
+    assert r.status_code == 200
+    links = sorted(x["href"] for x in BeautifulSoup(r.text).findAll("a"))
+    assert len(links) == 2
+    assert links == [
+        '../+f/202/cb962ac59075b/qpwoei-1.0.tar.gz#md5=202cb962ac59075b964b07152d234b70',
+        '../../../root/pypi/+e/https_pypi.python.org/qpwoei-1.0.zip']
+    testapp.xget(
+        200, URL("/%s/+simple/qpwoei" % api.stagename).joinpath(links[0]).path,
+        headers=headers)
+
 def test_project_redirect(pypistage, testapp):
     name = "qpwoei"
     headers = {'User-Agent': str('pip/1.4.1'), "Accept": str("text/html")}
@@ -395,9 +413,12 @@ class TestSubmitValidation:
             with testapp.xom.keyfs.transaction():
                 entry = testapp.xom.filestore.get_file_entry(path.strip("/"))
                 assert entry.file_exists()
+        # try a slightly different path and see if it fails
+        testapp.xget(404, path[:-2])
+
         mapp.delete_index(submit.stagename)
         for path in paths:
-            testapp.xget(404, path)
+            testapp.xget(410, path)
             with testapp.xom.keyfs.transaction():
                 entry = testapp.xom.filestore.get_file_entry(path.strip("/"))
                 assert not entry.file_exists()
@@ -421,7 +442,7 @@ class TestSubmitValidation:
         testapp.xget(200, path1)
         submit.file("pkg5-2.6.tgz", b"1234", {"name": "Pkg5"}, code=200)
         path2, = mapp.get_release_paths("Pkg5")
-        testapp.xget(404, path1)
+        testapp.xget(410, path1)  # existed once but deleted during overwrite
         testapp.xget(200, path2)
         r = testapp.xget(200, "%s/Pkg5/2.6" % mapp.api.index)
         link, = r.json['result']['+links']
@@ -640,7 +661,8 @@ def test_upload_and_push_internal(mapp, testapp, monkeypatch, proj):
     assert link.href.endswith("/pkg1-2.6.tgz")
 
 
-def test_upload_and_push_with_toxresults(mapp, testapp):
+@pytest.mark.parametrize("outside_url", ['', 'http://localhost/devpi'])
+def test_upload_and_push_with_toxresults(mapp, testapp, outside_url):
     from test_devpi_server.example import tox_result_data
     mapp.create_and_login_user("user1", "1")
     mapp.create_index("prod")
@@ -648,13 +670,14 @@ def test_upload_and_push_with_toxresults(mapp, testapp):
     mapp.use("user1/dev")
     mapp.upload_file_pypi("pkg1-2.6.tgz", b"123", "pkg1", "2.6", code=200)
     path, = mapp.get_release_paths("pkg1")
-    r = testapp.post(path, json.dumps(tox_result_data))
+    headers={str('X-outside-url'): str(outside_url)}
+    r = testapp.post(path, json.dumps(tox_result_data), headers=headers)
     # store a second toxresult
-    r = testapp.post(path, json.dumps(tox_result_data))
+    r = testapp.post(path, json.dumps(tox_result_data), headers=headers)
     assert r.status_code == 200
-    testapp.xget(200, path)
+    testapp.xget(200, path, headers=headers)
     req = dict(name="pkg1", version="2.6", targetindex="user1/prod")
-    r = testapp.push("/user1/dev", json.dumps(req))
+    r = testapp.push("/user1/dev", json.dumps(req), headers=headers)
     for actionlog in r.json["result"]:
         assert "user1/dev" not in actionlog[-1]
 
@@ -927,13 +950,6 @@ def test_upload_docs_no_project_ever_registered(mapp, testapp):
     content = zip_dict({"index.html": "<html/>"})
     mapp.upload_doc("pkg1.zip", content, "pkg1", "", code=400)
 
-def test_upload_docs_too_large(mapp):
-    from devpi_server.views import MAXDOCZIPSIZE
-    mapp.create_and_use()
-    content = b"*" * (MAXDOCZIPSIZE + 1)
-    mapp.set_versiondata(dict(name="pkg1", version="0.0"))
-    mapp.upload_doc("pkg1.zip", content, "pkg1", "2.6", code=413)
-
 @proj
 def test_upload_docs(mapp, testapp, proj):
     api = mapp.create_and_use()
